@@ -1,13 +1,15 @@
 from .cache.add import setup_caching
 from .deps import Require
 from .dual_router import DualAPIRouter, dualize_router
+from .ease import easy_service_api, easy_service_app
 from .models import APIVersionSpec, ServiceInfo
+from .routing import public_router
 from .setup import setup_service_api
-from .sugar import easy_service_api, easy_service_app
 
 __all__ = [
     "DualAPIRouter",
     "dualize_router",
+    "public_router",
     "ServiceInfo",
     "APIVersionSpec",
     "Require",
