@@ -5,10 +5,19 @@ from typing import Literal, cast
 from fastapi import FastAPI
 from starlette.middleware.sessions import SessionMiddleware
 
+from svc_infra.api.fastapi.auth.mfa import mfa_router
 from svc_infra.api.fastapi.db.sql.users import get_fastapi_users
 from svc_infra.app.env import CURRENT_ENVIRONMENT, DEV_ENV, LOCAL_ENV
+from svc_infra.db.sql.apikey import bind_apikey_model
 
+from .. import Require
+from .account import account_router
+from .apikey_router import apikey_router
+from .gaurd import login_client_guard, mfa_login_router
 from .oauth_router import oauth_router_with_backend
+from .openapi_security import install_openapi_auth
+from .policy import AuthPolicy, DefaultAuthPolicy
+from .pre_auth import get_mfa_pre_jwt_writer
 from .providers import providers_from_settings
 from .settings import get_auth_settings
 
@@ -25,29 +34,33 @@ def add_auth(
     oauth_prefix: str = "/auth/oauth",
     enable_password: bool = True,
     enable_oauth: bool = True,
+    enable_api_keys: bool = False,
+    apikey_table_name: str = "api_keys",
     provider_account_model=None,
+    auth_policy: AuthPolicy | None = None,
 ) -> None:
-    """
-    Wire auth into the app.
-
-    - Password login (/auth/jwt/*, /auth/users/*) is optional via enable_password.
-    - OAuth providers (/auth/oauth/*) are optional via enable_oauth.
-    """
-    fastapi_users, auth_backend, auth_router, users_router, _ = get_fastapi_users(
+    (
+        fapi,
+        auth_backend,
+        auth_router,
+        users_router,
+        get_strategy,
+        register_router,
+        verify_router,
+        reset_router,
+    ) = get_fastapi_users(
         user_model=user_model,
         user_schema_read=schema_read,
         user_schema_create=schema_create,
         user_schema_update=schema_update,
-        auth_prefix="/_sql" + auth_prefix,
+        public_auth_prefix=auth_prefix,
     )
 
-    # ---- settings & session middleware (for OAuth round-trip + cookie) & docs ----
     settings_obj = get_auth_settings()
+    policy = auth_policy or DefaultAuthPolicy(settings_obj)
     include_in_docs = CURRENT_ENVIRONMENT in (LOCAL_ENV, DEV_ENV)
 
-    # ensure SessionMiddleware mounted exactly once
     if not any(m.cls.__name__ == "SessionMiddleware" for m in app.user_middleware):
-        # Use JWT secret as session secret fallback
         jwt_block = getattr(settings_obj, "jwt", None)
         secret = (
             jwt_block.secret.get_secret_value()
@@ -67,16 +80,69 @@ def add_auth(
             https_only=bool(getattr(settings_obj, "session_cookie_secure", False)),
         )
 
-    # ---- Conditionally mount password-based auth ----
     if enable_password:
+        # Bind + mount (optional) API keys BEFORE adding the keys router
+        if enable_api_keys:
+            bind_apikey_model(user_model, table_name=apikey_table_name)
+            app.include_router(apikey_router(), include_in_schema=include_in_docs)
+
+        # MFA-aware login
         app.include_router(
-            auth_router, prefix=auth_prefix, tags=["auth"], include_in_schema=include_in_docs
+            mfa_login_router(
+                fapi=fapi,
+                auth_backend=auth_backend,
+                user_model=user_model,
+                get_mfa_pre_writer=get_mfa_pre_jwt_writer,
+                public_auth_prefix=auth_prefix,
+                auth_policy=policy,
+            ),
+            include_in_schema=include_in_docs,
+            dependencies=[Require(login_client_guard)],
         )
+
+        # Users & auth management
         app.include_router(
-            users_router, prefix=auth_prefix, tags=["users"], include_in_schema=include_in_docs
+            users_router,
+            prefix=auth_prefix,
+            tags=["users"],
+            include_in_schema=include_in_docs,
+        )
+        app.include_router(
+            register_router,
+            prefix=auth_prefix,
+            tags=["auth"],
+            include_in_schema=include_in_docs,
+        )
+        app.include_router(
+            verify_router,
+            prefix=auth_prefix,
+            tags=["auth"],
+            include_in_schema=include_in_docs,
+        )
+        app.include_router(
+            reset_router,
+            prefix=auth_prefix,
+            tags=["auth"],
+            include_in_schema=include_in_docs,
+        )
+
+        # MFA endpoints
+        app.include_router(
+            mfa_router(
+                user_model=user_model,
+                get_strategy=get_strategy,
+                fapi=fapi,
+                auth_prefix=auth_prefix,
+            ),
+            include_in_schema=include_in_docs,
+        )
+
+        # Account management
+        app.include_router(
+            account_router(user_model=user_model, auth_prefix=auth_prefix),
+            include_in_schema=include_in_docs,
         )
 
-    # ---- Conditionally mount OAuth providers ----
     if enable_oauth:
         providers = providers_from_settings(settings_obj)
         if providers:
@@ -84,11 +150,15 @@ def add_auth(
                 oauth_router_with_backend(
                     user_model=user_model,
                     auth_backend=auth_backend,
-                    providers=providers_from_settings(settings_obj),
+                    providers=providers,
                     post_login_redirect=post_login_redirect
                     or getattr(settings_obj, "post_login_redirect", "/"),
-                    prefix="/_sql" + oauth_prefix,
+                    prefix=oauth_prefix,
                     provider_account_model=provider_account_model,
+                    auth_policy=policy,
                 ),
                 include_in_schema=include_in_docs,
             )
+
+    if include_in_docs and (enable_password or enable_oauth or enable_api_keys):
+        install_openapi_auth(app)
